# Datasets


```{eval-rst}
.. module:: grassp.ds
```

```{eval-rst}
.. currentmodule:: grassp
```

Download public datasets in a preprocessed format.

## Public Datasets


```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   ds.hein_2024
   ds.itzhak_2016
   ds.schessner_2023
```

## Unpublished Datasets


```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   ds.hek_dc_2025
   ds.hek_atps_2025
```
